@@ -3,7 +3,7 @@ import logging
 logging.basicConfig(level=logging.INFO, format='%(message)s')
 
 
-def set_api(api_url, api_port):
+def setAPI(api_url, api_port):
     editList = ["BACK_END_API_URL = '{}'".format(api_url), 
                 '\n',
                 "BACK_END_API_PORT = '{}'".format(api_port)]
