@@ -97,7 +97,7 @@ class from_model(object):
             parvalue = itemgetter(*parkey)(self.parDict)
             parvalue = list(parvalue)
         
-            parkey = list(map(lambda x: x[x.find('__')+2:], parkey))
+            parkey = list(map(lambda x: x[x.find('__') + 2:], parkey))
             
             all_dict = dict()
             for i in range(len(parkey)):
@@ -106,18 +106,18 @@ class from_model(object):
             if 'random_state' in all_dict.keys():
                 all_dict.pop('random_state')
             
-            return(all_dict)
+            return all_dict
         
         # binary
         except TypeError:
-            return(self.parDict)
+            return self.parDict
     
     def param_keys(self):
-        parkey =  [i for i in self.parDict.keys() if '__' in i]
-        parkey = list(map(lambda x: x[x.find('__')+2:], parkey))
+        parkey = [i for i in self.parDict.keys() if '__' in i]
+        parkey = list(map(lambda x: x[x.find('__') + 2:], parkey))
         if len(parkey) != 0:
             parkey.remove('random_state')
-            return(parkey)
+            return parkey
         else:
             return list(self.parDict.keys())
 
