@@ -41,8 +41,8 @@ class RestStore:
 
             response = verify_rest_response(response, endpoint).text
 
-        except Exception:
-            logging.error("Modeler API server connection failed")
+        except Exception as e:
+            logging.error("Modeler API server connection failed: ", e)
             response = None
 
         return response
